Module consumer

Module consumer 

Consuming an ordered log of binary payloads from a track.

Re-exports

pub use super::Config;

Structs

Consumer
Consumes an ordered log of binary payloads from a track, yielding every one.