Module producer

Module producer 

Publishing an ordered log of binary payloads over a track.

Re-exports

pub use super::Config;

Structs

Producer
Publishes an ordered log of binary payloads over a track, one payload per frame in a single group.